Learn R Programming

rregm (version 1.0)

tools.rregm: Print a summary for a object of the "rregm" class.

Description

Tools for a objects of the "rregm" class.

Usage

res(object, type="pearson")
# S3 method for rregm
AIC(object, ..., k=2)
# S3 method for rregm
BIC(object, ...)
# S3 method for rregm
coef(object, ...)
# S3 method for rregm
logLik(object, ...)
# S3 method for rregm
print(x, digits = max(3L, getOption("digits") - 3L), ...)
# S3 method for rregm
summary(object, ...)

Value

A complete summary for the coefficients extracted from a "rregm" object.

Arguments

x, object

an object of the "rregm" class.

type

type of residuals to be presented: pearson (default), mod.pearson or quantile.

digits

minimal number of significant digits

k

numeric, the penalty per parameter to be used; the default k = 2 is the classical AIC.

...

for extra arguments.

Author

Diego Gallardo and Marcelo Bourguignon.

Details

Supported regression models are: - reparametrized beta - reparametrized gamma - reparametrized beta prime - reparametrized inverse gamma

References

Gallardo and Bourguignon (2022).

Examples

Run this code
set.seed(2100)
n=100; x1=rnorm(max(n)) ##drawing covariates, the same for mu and sigma
mu=exp(0.5-0.4*x1); sigma=exp(-0.1+0.05*x1)
y=rRGA(n, mu, sigma, param="MD") ## model parameterized in the median
data=list(y=y, x1=x1)
aux.RGA=fit.RGA(y~x1, sigma.formula=~x1, data=data, param="MD")
summary(aux.RGA)
qqnorm(res(aux.RGA, type="mod.pearson"))

Run the code above in your browser using DataLab